Class FlowableProcessBusinessStatusUpdatedEventImpl
java.lang.Object
org.flowable.common.engine.impl.event.FlowableEventImpl
org.flowable.common.engine.impl.event.FlowableEngineEventImpl
org.flowable.engine.delegate.event.impl.FlowableProcessBusinessStatusUpdatedEventImpl
- All Implemented Interfaces:
FlowableEngineEntityEvent,FlowableEngineEvent,FlowableEntityEvent,FlowableEvent,FlowableProcessBusinessStatusUpdatedEvent
public class FlowableProcessBusinessStatusUpdatedEventImpl
extends FlowableEngineEventImpl
implements FlowableProcessBusinessStatusUpdatedEvent
-
Field Summary
FieldsFields inherited from class org.flowable.common.engine.impl.event.FlowableEngineEventImpl
scopeDefinitionId, scopeId, scopeType, subScopeIdFields inherited from class org.flowable.common.engine.impl.event.FlowableEventImpl
type -
Constructor Summary
ConstructorsConstructorDescriptionFlowableProcessBusinessStatusUpdatedEventImpl(ExecutionEntity execution, String oldBusinessStatus, String newBusinessStatus) -
Method Summary
Modifier and TypeMethodDescriptionReturns the business status of the process after the update.Returns the business status of the process before the update.Methods inherited from class org.flowable.common.engine.impl.event.FlowableEngineEventImpl
getExecutionId, getProcessDefinitionId, getProcessInstanceId, getScopeDefinitionId, getScopeId, getScopeType, getSubScopeId, getType, setExecutionId, setProcessDefinitionId, setProcessInstanceId, setScopeDefinitionId, setScopeId, setScopeType, setSubScopeId, setTypeMethods inherited from class org.flowable.common.engine.impl.event.FlowableEventImpl
toStringMethods inherited from class java.lang.Object
clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, waitMethods inherited from interface org.flowable.common.engine.api.delegate.event.FlowableEngineEvent
getExecutionId, getProcessDefinitionId, getProcessInstanceId, getScopeDefinitionId, getScopeId, getScopeType, getSubScopeIdMethods inherited from interface org.flowable.common.engine.api.delegate.event.FlowableEvent
getType
-
Field Details
-
execution
-
oldBusinessStatus
-
newBusinessStatus
-
-
Constructor Details
-
FlowableProcessBusinessStatusUpdatedEventImpl
public FlowableProcessBusinessStatusUpdatedEventImpl(ExecutionEntity execution, String oldBusinessStatus, String newBusinessStatus)
-
-
Method Details
-
getEntity
- Specified by:
getEntityin interfaceFlowableEntityEvent
-
getOldBusinessStatus
Description copied from interface:FlowableProcessBusinessStatusUpdatedEventReturns the business status of the process before the update.- Specified by:
getOldBusinessStatusin interfaceFlowableProcessBusinessStatusUpdatedEvent- Returns:
- the old business status
-
getNewBusinessStatus
Description copied from interface:FlowableProcessBusinessStatusUpdatedEventReturns the business status of the process after the update.- Specified by:
getNewBusinessStatusin interfaceFlowableProcessBusinessStatusUpdatedEvent- Returns:
- the new business status
-